@@ -619,7 +619,7 @@ class EpisodeInfo(object):
     def sortable_info(self):
         """Returns a tuple of sortable information
         """
-        return (self.seriesname, self.seasonnumber, self.episodenumbers)
+        return ("%s" % self.seriesname, self.seasonnumber, self.episodenumbers)
 
     def number_string(self):
         """Used in UI
@@ -831,7 +831,7 @@ class DatedEpisodeInfo(EpisodeInfo):
     def sortable_info(self):
         """Returns a tuple of sortable information
         """
-        return (self.seriesname, self.episodenumbers)
+        return ("%s" % (self.seriesname), self.episodenumbers)
 
     def number_string(self):
         """Used in UI
@@ -894,7 +894,7 @@ class NoSeasonEpisodeInfo(EpisodeInfo):
     def sortable_info(self):
         """Returns a tuple of sortable information
         """
-        return (self.seriesname, self.episodenumbers)
+        return ("%s" % self.seriesname, self.episodenumbers)
 
     def number_string(self):
         """Used in UI
